pub struct CreateNonceInstructionArgs {
pub guid: [u8; 16],
}Fields
guid: [u8; 16]Trait Implementations
Sourceimpl BorshDeserialize for CreateNonceInstructionArgs
impl BorshDeserialize for CreateNonceInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateNonceInstructionArgs
impl Clone for CreateNonceInstructionArgs
Sourcefn clone(&self) -> CreateNonceInstructionArgs
fn clone(&self) -> CreateNonceInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateNonceInstructionArgs
impl Debug for CreateNonceInstructionArgs
impl Eq for CreateNonceInstructionArgs
impl StructuralPartialEq for CreateNonceInstructionArgs